package com.zy.omp.controller.wx;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zy.omp.common.ServerResponse;
import com.zy.omp.common.controller.BaseController;
import com.zy.omp.model.Device;
import com.zy.omp.model.Relation;
import com.zy.omp.service.DeviceInfoStateService;
import com.zy.omp.service.DeviceService;
import com.zy.omp.service.RelationService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 设备 Controller
 *
 * @author yang xiao kun
 * create on 2021/10/18
 */
@RestController
@RequestMapping("omp/api/wx/device")
public class DeviceController extends BaseController {

    @Resource
    private DeviceInfoStateService deviceInfoStateService;
    @Resource
    private RelationService relationService;
    @Resource
    private DeviceService deviceService;

    /**
     * 查询设备最新的状态信息
     */
    @GetMapping("getLatestDetail.do")
    public ServerResponse getLatestDetail(String openNum) {
        return ServerResponse.createBySuccess(deviceInfoStateService.getDeviceLatestDetail(openNum, getOpenId()));
    }

    /**
     * 查询用户绑定的设备
     */
    @GetMapping("listBindDevices.do")
    public ServerResponse listBindDevices() {
        return ServerResponse.createBySuccess(relationService.listByOpenId(getOpenId()));
    }

    /**
     * 切换默认设备
     */
    @PostMapping("switchDefault.do")
    public ServerResponse setDefault(String openNum) {
        return ServerResponse.createBySuccess(relationService.updateDefaultDevice(openNum, getOpenId()));
    }

    /**
     * 更新设备名称
     */
    @PostMapping("updateName.do")
    public ServerResponse updateName(Relation relation) {
        relation.setOpenId(getOpenId());
        return ServerResponse.createBySuccess(relationService.updateDeviceName(relation));
    }

    /**
     * 添加绑定关系
     */
    @PostMapping("bind.do")
    public ServerResponse bind(Relation relation) {
        //校验设备码有效性
        if (deviceService.getOne(new QueryWrapper<Device>().eq("openNum", relation.getOpenNum())) == null)
            return ServerResponse.createByWarning("设备码无效!");
        if (relationService.getOne(new QueryWrapper<Relation>().eq("openNum", relation.getOpenNum()).eq("openId", getOpenId())) != null) {
            return ServerResponse.createByWarning("已经绑定该设备!");
        }
        relation.setOpenId(getOpenId());
        relationService.saveRelation(relation);
        return ServerResponse.createBySuccess();
    }

    /**
     * 解除绑定关系
     */
    @PostMapping("unbind.do")
    public ServerResponse unbind(String openNum) {
        return ServerResponse.createBySuccess(relationService.remove(new QueryWrapper<Relation>().eq("openNum", openNum).eq("openId", getOpenId())));
    }

}
