package com.zy.omp.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.omp.mapper.RelationMapper;
import com.zy.omp.model.Relation;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户设备绑定关系Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class RelationService extends ServiceImpl<RelationMapper, Relation> {

    /**
     * 查询用户的所有设备
     *
     * @param openId 用户ID
     */
    public List<Relation> listByOpenId(String openId) {
        return baseMapper.selectList(new QueryWrapper<Relation>().select("openNum", "deviceName", "isDefault")
                .eq("openId", openId).orderByDesc("isDefault", "updateTime"));
    }

    /**
     * 切换默认设备
     */
    public boolean updateDefaultDevice(String openNum, String openId) {
        return baseMapper.updateDefaultDevice(openNum, openId) > 0;
    }

    /**
     * 更新设备名称
     */
    public boolean updateDeviceName(Relation relation) {
        return update(new UpdateWrapper<Relation>()
                .set("deviceName", relation.getDeviceName())
                .eq("openId", relation.getOpenId())
                .eq("openNum", relation.getOpenNum()));
    }

    /**
     * 保存设备绑定关系
     *
     * @return 当前绑定的设备列表
     */
    public void saveRelation(Relation relation) {
        //保存新纪录
        save(relation);
        //设置默认设备
        updateDefaultDevice(relation.getOpenNum(), relation.getOpenId());
    }

    /**
     * 查询设备是否有绑定关系
     *
     * @param openNum 设备ID
     */
    public boolean checkBind(String openNum) {
        return baseMapper.checkBind(openNum) > 0;
    }

    /**
     * 查询设备是否属于该用户
     *
     * @param openId  用户ID
     * @param openNum 设备ID
     */
    public boolean checkBelong(String openNum, String openId) {
        return baseMapper.checkBelong(openNum, openId) > 0;
    }
}
